@@ -1,15 +1,16 @@
 import argparse
 import os
-import shutil
-from pathlib import Path
+import sys
 
-import tomlkit
+import isort
+from gitbetter import git
+from pathier import Pathier
 
 from hassle import hassle_utilities
 from hassle.generate_tests import generate_test_files
 from hassle.run_tests import run_tests
 
-root = Path(__file__).parent
+root = Pathier(__file__).parent
 
 
 def get_args() -> argparse.Namespace:
@@ -133,9 +134,16 @@ def get_args() -> argparse.Namespace:
         To publish the updated package, the -p/--publish switch needs to be added to the cli input.""",
     )
 
+    parser.add_argument(
+        "-st",
+        "--skip_tests",
+        action="store_true",
+        help=""" Don't run tests when using the -b/--build command. """,
+    )
+
     args = parser.parse_args()
 
-    args.package = Path(args.package).resolve()
+    args.package = Pathier(args.package).resolve()
 
     if args.update:
         args.build = True
@@ -161,11 +169,43 @@ def get_args() -> argparse.Namespace:
     return args
 
 
+def build(
+    package_dir: Pathier, skip_tests: bool = False, overwrite_dependencies: bool = False
+):
+    """Perform the build process.
+
+    Steps:
+    * Run tests (unless `skip_tests` is `True`)
+    * Raise error and abandon build if tests fail
+    * Format source code with `Black`
+    * Sort source code imports with `isort`
+    * Update project dependencies in `pyproject.toml`
+    * Generate docs
+    * Delete previous `dist` folder contents
+    * Invoke build module"""
+    if not skip_tests and not run_tests(package_dir):
+        raise RuntimeError(
+            f"ERROR: {package_dir.stem} failed testing.\nAbandoning build."
+        )
+    hassle_utilities.format_files(package_dir)
+    [isort.file(path) for path in package_dir.rglob("*.py")]
+    hassle_utilities.update_dependencies(
+        package_dir / "pyproject.toml", overwrite_dependencies
+    )
+    # Vermin isn't taking into account the minimum version of dependencies.
+    # Removing from now and defaulting to >=3.10
+    # hassle_utilities.update_minimum_python_version(pyproject_path)
+    hassle_utilities.generate_docs(package_dir)
+    (package_dir / "dist").delete()
+    os.system(f"{sys.executable} -m build {package_dir}")
+
+
 def main(args: argparse.Namespace = None):
     if not args:
         args = get_args()
 
     pyproject_path = args.package / "pyproject.toml"
+    args.package.mkcwd()
 
     if not pyproject_path.exists():
         raise FileNotFoundError(f"Could not locate pyproject.toml for {args.package}")
@@ -180,35 +220,26 @@ def main(args: argparse.Namespace = None):
         hassle_utilities.increment_version(pyproject_path, args.increment_version)
 
     if args.build:
-        try:
-            shutil.rmtree(f"{args.package}/dist")
-        except Exception as e:
-            pass
-        os.system(f"black {args.package}")
-        os.system(f"isort {args.package}")
-        hassle_utilities.update_dependencies(
-            pyproject_path, args.overwrite_dependencies
-        )
-        hassle_utilities.update_minimum_python_version(pyproject_path)
-        hassle_utilities.generate_docs(args.package)
-        os.system(f"py -m build {args.package}")
+        build(args.package, args.skip_tests, args.overwrite_dependencies)
 
     if args.update_changelog:
         hassle_utilities.update_changelog(pyproject_path)
         # If we're going to add tag for current version
         # commit changelog first
         if args.tag_version:
-            os.chdir(args.package)
-            os.system("git add CHANGELOG.md")
-            os.system('git commit CHANGELOG.md -m "chore: update changelog"')
+            input(
+                "Press enter to continue after optionally pruning the updated changelog..."
+            )
+            git.commit_files(
+                [str(args.package / "CHANGELOG.md")], "chore: update changelog"
+            )
 
     if args.commit_all:
-        os.chdir(args.package)
         if args.commit_all == "build":
-            version = tomlkit.loads(pyproject_path.read_text())["project"]["version"]
+            version = pyproject_path.loads()["project"]["version"]
             args.commit_all = f"chore: build v{version}"
-        os.system("git add .")
-        os.system(f'git commit -m "{args.commit_all}"')
+        git.add()
+        git.commit(f'-m "{args.commit_all}"')
 
     if args.tag_version:
         hassle_utilities.tag_version(args.package)
@@ -220,9 +251,8 @@ def main(args: argparse.Namespace = None):
         os.system(f"pip install {args.package} --no-deps --upgrade --no-cache-dir")
 
     if args.sync:
-        os.chdir(args.package)
-        os.system(f"git pull --tags origin main")
-        os.system(f"git push origin main:main --tags")
+        git.pull("--tags")
+        git.push("--tags")
 
 
 if __name__ == "__main__":
