@@ -1,18 +1,17 @@
 import argparse
 import os
-import shutil
 import sys
 from datetime import datetime
-from pathlib import Path
 
 import requests
-import tomlkit
 from bs4 import BeautifulSoup
+from gitbetter import git
+from pathier import Pathier
 
 import hassle.hassle_config as hassle_config
 from hassle.generate_tests import generate_test_files
 
-root = Path(__file__).parent
+root = Pathier(__file__).parent
 
 
 def get_args() -> argparse.Namespace:
@@ -109,8 +108,7 @@ def get_args() -> argparse.Namespace:
 
 
 def get_answer(question: str) -> bool:
-    """Repeatedly ask the user a yes/no question
-    until a 'y' or a 'n' is received."""
+    """Repeatedly ask the user a yes/no question until a 'y' or a 'n' is received."""
     ans = ""
     question = question.strip()
     if "?" not in question:
@@ -127,9 +125,8 @@ def get_answer(question: str) -> bool:
 
 
 def check_pypi_for_name(package_name: str) -> bool:
-    """Check if a package with package_name
-    already exists on pypi.org .
-    Returns True if package name exists.
+    """Check if a package with package_name already exists on `pypi.org`.
+    Returns `True` if package name exists.
     Only checks the first page of results."""
     url = f"https://pypi.org/search/?q={package_name.lower()}"
     response = requests.get(url)
@@ -155,10 +152,9 @@ def check_pypi_for_name_cli():
         print(f"{args.name} is available.")
 
 
-def create_pyproject_file(targetdir: Path, args: argparse.Namespace):
-    """Create pyproject.toml in ./{project_name} from args,
-    pyproject_template, and hassle_config."""
-    pyproject = tomlkit.loads((root / "pyproject_template.toml").read_text())
+def create_pyproject_file(targetdir: Pathier, args: argparse.Namespace):
+    """Create `pyproject.toml` in `./{project_name}` from args, pyproject_template, and hassle_config."""
+    pyproject = (root / "pyproject_template.toml").loads()
     if not hassle_config.config_exists():
         hassle_config.warn()
         if not get_answer("Continue creating new package with blank config?"):
@@ -184,19 +180,18 @@ def create_pyproject_file(targetdir: Path, args: argparse.Namespace):
         )
     if args.add_script:
         pyproject["project"]["scripts"][args.name] = f"{args.name}.{args.name}:main"
-    (targetdir / "pyproject.toml").write_text(tomlkit.dumps(pyproject))
+    (targetdir / "pyproject.toml").dumps(pyproject)
 
 
-def create_source_files(srcdir: Path, filelist: list[str]):
-    """Generate empty source files in ./{package_name}/src/{package_name}/"""
+def create_source_files(srcdir: Pathier, filelist: list[str]):
+    """Generate empty source files in `./{package_name}/src/{package_name}/`"""
     srcdir.mkdir(parents=True, exist_ok=True)
     for file in filelist:
         (srcdir / file).touch()
 
 
-def create_readme(targetdir: Path, args: argparse.Namespace):
-    """Create README.md in ./{package_name}
-    from readme_template and args."""
+def create_readme(targetdir: Pathier, args: argparse.Namespace):
+    """Create `README.md` in `./{package_name}` from readme_template and args."""
     readme = (root / "README_template.md").read_text()
     readme = readme.replace("$name", args.name).replace(
         "$description", args.description
@@ -204,23 +199,23 @@ def create_readme(targetdir: Path, args: argparse.Namespace):
     (targetdir / "README.md").write_text(readme)
 
 
-def create_license(targetdir: Path):
-    """Add MIT license file to ./{package_name} ."""
+def create_license(targetdir: Pathier):
+    """Add MIT license file to `./{package_name}`."""
     license_template = (root / "license_template.txt").read_text()
     license_template = license_template.replace("$year", str(datetime.now().year))
     (targetdir / "LICENSE.txt").write_text(license_template)
 
 
-def create_gitignore(targetdir: Path):
-    """Add .gitignore to ./{package_name}"""
-    shutil.copy(root / ".gitignore_template", targetdir / ".gitignore")
+def create_gitignore(targetdir: Pathier):
+    """Add `.gitignore` to `./{package_name}`"""
+    (root / ".gitignore_template").copy(targetdir / ".gitignore", True)
 
 
-def create_vscode_settings(targetdir: Path):
-    """Add settings.json to ./.vscode"""
+def create_vscode_settings(targetdir: Pathier):
+    """Add `settings.json` to `./.vscode`"""
     vsdir = targetdir / ".vscode"
     vsdir.mkdir(parents=True, exist_ok=True)
-    shutil.copy(root / ".vscode_template", vsdir / "settings.json")
+    (root / ".vscode_template").copy(vsdir / "settings.json", True)
 
 
 def main(args: argparse.Namespace = None):
@@ -240,7 +235,7 @@ def main(args: argparse.Namespace = None):
             if not get_answer("Continue anyway?"):
                 sys.exit(0)
     try:
-        targetdir = Path.cwd() / args.name
+        targetdir: Pathier = Pathier.cwd() / args.name
         try:
             targetdir.mkdir(parents=True, exist_ok=False)
         except:
@@ -261,13 +256,13 @@ def main(args: argparse.Namespace = None):
         if not args.no_license:
             create_license(targetdir)
         os.chdir(targetdir)
-        os.system("git init -b main")
+        git.new_repo()
 
     except Exception as e:
         if not "Aborting new package creation" in str(e):
             print(e)
         if get_answer("Delete created files?"):
-            shutil.rmtree(targetdir)
+            targetdir.delete()
 
 
 if __name__ == "__main__":
