@@ -1,6 +1,9 @@
 import argparse
 import os
-from pathlib import Path
+
+import coverage
+import pytest
+from pathier import Pathier
 
 
 def get_args() -> argparse.Namespace:
@@ -22,20 +25,25 @@ def get_args() -> argparse.Namespace:
     return args
 
 
-def run_tests(package_path: Path):
-    """Run tests with coverage and pytest."""
-    startdir = Path().cwd()
-    os.chdir(package_path)
-    os.system(f"pip install -e .")
-    os.system(f"coverage run -m pytest -s")
-    os.system(f"coverage report -m")
-    os.chdir(startdir)
+def run_tests(package_path: Pathier) -> bool:
+    """Run tests with coverage and pytest.
+
+    Returns True if all tests passed."""
+    startdir = Pathier().cwd()
+    package_path.mkcwd()
+    cover = coverage.Coverage()
+    cover.start()
+    results = pytest.main(["-s"])
+    cover.stop()
+    cover.report()
+    startdir.mkcwd()
+    return results == 0
 
 
 def main(args: argparse.Namespace = None):
     if not args:
         args = get_args()
-    package_path = Path(args.package_name).resolve()
+    package_path = Pathier(args.package_name).resolve()
     run_tests(package_path)
 
 
